==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/photos/l10n/mk.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Јавен линк",
    "Photos" : "Фотографии",
    "Your memories under your control" : "Вашите спомени под ваша контрола",
    "All media" : "Сите медиуми",
    "Videos" : "Видеа",
    "Albums" : "Албуми",
    "Collaborative albums" : "Колаборативни албуми",
    "People" : "Луѓе",
    "Folders" : "Папки",
    "Favorites" : "Омилени",
    "On this day" : "На денешен ден",
    "Shared with you" : "Споделено со вас",
    "Tags" : "Ознаки",
    "Places" : "Места",
    "Map" : "Мапа",
    "Photos settings" : "Параметри за фотографиите",
    "Mark selection as favorite" : "Означи ги селектираните како омилени",
    "Add selection to favorites" : "Означи ги селектираните како омилени",
    "Remove selection from favorites" : "Отстрани ги селектираните од омилени",
    "Name of the album" : "Име на албумот",
    "Location of the album" : "Локација на албумот",
    "Back" : "Назад",
    "Add collaborators" : "Додади соработници",
    "Save" : "Зачувај",
    "Create album" : "Креирај албум",
    "Add to Album" : "Додади во албум",
    "Add selection to album {albumName}" : "Додади ги избраните во албумот {albumName}",
    "Shared by" : "Споделено од",
    "Create a new album." : "Креирај нов албум.",
    "Create new album" : "Креирај нов албум",
    "New album" : "Нов албум",
    "_%n item_::_%n photos and videos_" : ["1 објект","%n фотографии и видеа"],
    "Add people or groups who can edit your album" : "Додади корисник кој ќе може да го ажурира твојот албум",
    "Search people or groups" : "Пребарувај луѓе и групи",
    "No recommendations. Start typing." : "Нема препораки. Започнете со пишување.",
    "Remove {collaboratorLabel} from the collaborators list" : "Избриши {collaboratorLabel} од листата на соработници",
    "Copy the public link" : "Копирај јавен линк",
    "Public link copied!" : "Јавниот линк е копиран!",
    "Copy public link" : "Копирај јавен линк",
    "Delete the public link" : "Избриши јавен линк",
    "Share via public link" : "Сподели преку јавен линк",
    "Failed to fetch collaborators list." : "Неуспешно добивање на листа со соработници.",
    "Failed to update album." : "Неуспешно ажурирање на албум.",
    "This collection does not exist" : "Оваа колекција не постои",
    "An error occurred" : "Настана грешка",
    "Favorite" : "Омилени",
    "Select image {imageName}" : "Избери слика {imageName}",
    "Open the full size \"{name}\" image" : "Отвори ја сликата \"{name}\" во целосна големина",
    "There are no photos or videos yet!" : "Овде сеуште нема фотографии и видеа!",
    "Add to {destination}" : "Додај до {destination}",
    "Go back" : "Назад",
    "Back to {folder}" : "Назад кон {folder}",
    "Share this folder" : "Сподели ја оваа папка",
    "_{years} year ago_::_{years} years ago_" : ["пред 1 година","пред {years} години"],
    "Enable squared photos view" : "Овозможи поглед на фотографиите во квадрати",
    "Default Photos upload and Albums location" : "Стандардна локација за прикачени фотографии и албуми",
    "Select the default location for your media" : "Изберете стандардна локација за вашите медиа датотеки",
    "Invalid location selected" : "Избрана невалидна локација",
    "View" : "Погледни",
    "Photos directory" : "Директориум за фотографии",
    "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографии"],
    "Unselect all" : "Од-означи се",
    "Manage collaborators for this album" : "Уреди соработници за овој албум",
    "Open actions menu" : "Отвори Мени со акции",
    "Edit album details" : "Уреди ги деталите на албумот",
    "Download all files in album" : "Преземи ги сите датотеки од албумот",
    "Delete album" : "Избриши албум",
    "Download selected files" : "Преземи ги означените датотеки",
    "Remove selection from album" : "Отстрани ги селектираните од албумот",
    "This album does not have any photos or videos yet!" : "Овој албум сеуште нема фотографии и видеа!",
    "Add photos to this album" : "Додади фотографии во овој албум",
    "Manage collaborators" : "Уреди соработници",
    "Save collaborators for this album." : "Зачувај соработници за овој албум.",
    "Cover photo for album {albumName}" : "Насловна фотографија за албумот {albumName}",
    "There is no album yet!" : "Сè уште нема албум!",
    "This person could not be found" : "Оваа личност неможе да се пронајде",
    "Rename person" : "Преименувај личност",
    "Merge with different person" : "Спој со друга личност",
    "Download selected photos" : "Преземи ги означените фотографии",
    "Remove from favorites" : "Отстрани од фаворити",
    "Remove person" : "Отстрани личност",
    "Name of this person" : "Име на личноста",
    "Save." : "Зачувај.",
    "Merge person" : "Спој личност",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Премести ја фотографијата до друга особа","Премести ги фотографиите до друга особа"],
    "_Remove photo from person_::_Remove photos from person_" : ["Отстрани фотографија од личност","Отстрани фотографии од личност"],
    "This might take some time depending on the size of your photo library." : "Ова може да потрае некое време во зависност од големината на вашата збирка со фотографии.",
    "Recognized people will show up here" : "Препознатите луѓе ќе се појават овде",
    "This folder does not exist" : "Папката не постои",
    "Loading folders …" : "Се вчитуваат папките…",
    "No photos in here" : "Овде нема фотографии",
    "This place does not have any photos or videos yet!" : "Ова место сеуште нема фотографии и видеа!",
    "Add photos to this place" : "Додади фотографии во ова место",
    "Cover photo for place {placeName}" : "Насловна фотографија за местото {placeName}",
    "There is no place yet!" : "Сè уште нема места!",
    "Cover photo for shared album {albumName}." : "Насловна фотографија за споделениот албум {albumName}",
    "Back to tags overview" : "Назад до преглед на ознаки",
    "No photos with this tag yet" : "Сеуште нема фотографии со оваа ознака",
    "No tags yet" : "Сеуште нема ознаки",
    "Photos with tags will show up here" : "Фотографиите со ознаки ќе се појават овде",
    "Popular tags" : "Популарни ознаки",
    "Add" : "Додади",
    "Add to album" : "Додади во албум",
    "Delete selection" : "Избриши ги селектираните",
    "No photos or videos in here" : "Овде нема фотографии или видеа",
    "_%n photos_::_%n photos_" : ["1 фотографија","%n фотографии"],
    "Failed to fetch collection." : "Неуспешно добивање на колекциите.",
    "Failed to fetch collections list." : "Неуспешно добивање на листата со колекции.",
    "Failed to fetch faces list." : "Неуспешно вчитување на листата со личности.",
    "All your media" : "Сите ваши медиа датотеки",
    "Album {title}" : "Албум {title}",
    "Shared Albums" : "Споделени албуми",
    "Shared album {title}" : "Споделен албум {title}",
    "Public album {title}" : "Јавен албум {title}",
    "Tagged photos" : "Означени фотографии",
    "Tagged photo {title}" : "Означена фотографија {title}",
    "{title}'s face" : "Лицето на {title}",
    "{startDate} to {endDate}" : "{startDate} до {endDate}",
    "Details" : "Детали",
    "Failed to rename {oldName} to {faceName}." : "Неуспешно преименување на {oldName} во {faceName}.",
    "Failed to delete {faceName}." : "Неуспешно бришење на {faceName}.",
    "Failed to delete {fileId}." : "Неуспешно бришење на {fileId}.",
    "Failed to delete {fileName}." : "Неуспешно бришење на {fileName}.",
    "Failed to set favorite state for {fileId}." : "Неуспешно поставување на омилен статус за {fileId}.",
    "Failed to set favorite state for {fileName}." : "Неуспешно поставување на омилен статус за {fileName}.",
    "Go back to the previous view." : "Врати се на предходниот поглед",
    "Go to the add collaborators view." : "Оди за да додадеш соработници",
    "Create the album." : "Креирај го албумот.",
    "Back to the new album form." : "Врати се на формата за нов албум.",
    "_Share with %n user_::_Share with %n users_" : ["Споделено со 1 корисник","Споделено со %n корисници"],
    "Search for collaborators" : "Барај соработници",
    "Add {collaboratorLabel} to the collaborators list" : "Додади {collaboratorLabel} на листата на соработници",
    "No collaborators available" : "Нема достапни соработници",
    "Failed to fetch album." : "Неуспешно добивање на албум",
    "The file is in the favorites" : "Оваа датотека е во омилеми",
    "Open the \"{name}\" sub-directory" : "Отвори го поддиректориумот \"{name}\"",
    "Add photos to the album" : "Додади фотографии во албумот",
    "Failed to fetch albums list." : "Неуспешно добивање на листа со албуми.",
    "Shared albums" : "Споделени албуми",
    "Create a new album" : "Креирај нов албум",
    "Add selection to an album" : "Додади ги избраните во албумот",
    "Failed to create {albumName}." : "Неуспешно креирање {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Неуспешно преименување на {currentAlbumName} во {newAlbumName}."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> php83-nextcloud-30.0.15.tgz: share/nextcloud/apps/photos/l10n/mk.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Јавен линк",
    "Photos" : "Фотографии",
    "On This Day" : "На денешен ден",
    "Your memories under your control" : "Вашите спомени под ваша контрола",
    "All media" : "Сите медиуми",
    "Videos" : "Видеа",
    "Albums" : "Албуми",
    "Collaborative albums" : "Колаборативни албуми",
    "People" : "Луѓе",
    "Folders" : "Папки",
    "Favorites" : "Омилени",
    "On this day" : "На денешен ден",
    "Shared with you" : "Споделено со вас",
    "Tags" : "Ознаки",
    "Places" : "Места",
    "Map" : "Мапа",
    "Photos settings" : "Параметри за фотографиите",
    "Mark selection as favorite" : "Означи ги селектираните како омилени",
    "Add selection to favorites" : "Означи ги селектираните како омилени",
    "Remove selection from favorites" : "Отстрани ги селектираните од омилени",
    "Name of the album" : "Име на албумот",
    "Location of the album" : "Локација на албумот",
    "Back" : "Назад",
    "Add collaborators" : "Додади соработници",
    "Save" : "Зачувај",
    "Create album" : "Креирај албум",
    "Add to Album" : "Додади во албум",
    "Add selection to album {albumName}" : "Додади ги избраните во албумот {albumName}",
    "Shared by" : "Споделено од",
    "Create a new album." : "Креирај нов албум.",
    "Create new album" : "Креирај нов албум",
    "New album" : "Нов албум",
    "_%n item_::_%n photos and videos_" : ["1 објект","%n фотографии и видеа"],
    "Failed to fetch collaborators list." : "Неуспешно добивање на листа со соработници.",
    "Failed to update album." : "Неуспешно ажурирање на албум.",
    "Add people or groups who can edit your album" : "Додади корисник кој ќе може да го ажурира твојот албум",
    "Search people or groups" : "Пребарувај луѓе и групи",
    "No recommendations. Start typing." : "Нема препораки. Започнете со пишување.",
    "Copy the public link" : "Копирај јавен линк",
    "Public link copied!" : "Јавниот линк е копиран!",
    "Copy public link" : "Копирај јавен линк",
    "Delete the public link" : "Избриши јавен линк",
    "Create public link share" : "Креирај споделување со јавен линк",
    "Share via public link" : "Сподели преку јавен линк",
    "This collection does not exist" : "Оваа колекција не постои",
    "An error occurred" : "Настана грешка",
    "No picture for this day" : "Нема слика за овој ден",
    "Picture taken on this day will show up here." : "Сликите направени на денешен ден ќе се појават тука.",
    "More photos from this day" : "Повеќе фотографии од овој ден",
    "_%n photos_::_%n photos_" : ["1 фотографија","%n фотографии"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n неозначена фотографија","%n неозначени фотографии"],
    "Favorite" : "Омилени",
    "Favorite image, open the full size \"{name}\" image" : "Омилени слики, прикажи оргинална големина \"{name}\" ",
    "Open the full size \"{name}\" image" : "Отвори ја сликата \"{name}\" во целосна големина",
    "Select image {imageName}" : "Избери слика {imageName}",
    "Open the \"{name}\" folder" : "Отвори ја папката на \"{name}\"",
    "Go back" : "Назад",
    "Select a date range" : "Избери опсег",
    "Date range" : "Опсег",
    "Select filters" : "Избери филтри",
    "Dates" : "Датуми",
    "Jump to specific date in list" : "Оди го одреден датум на листата",
    "Jump to {date}" : "Оди до {date}",
    "Add to {destination}" : "Додај до {destination}",
    "The destination folder is owned by {owner}" : "Папката е во сопственост на {owner}",
    "There are no photos or videos yet!" : "Овде сеуште нема фотографии и видеа!",
    "_{years} year ago_::_{years} years ago_" : ["пред 1 година","пред {years} години"],
    "Enable squared photos view" : "Овозможи поглед на фотографиите во квадрати",
    "Pick folder" : "Избери папка",
    "All folders" : "Сите папки",
    "Add folder" : "Додади папка",
    "Select the default upload location for your media" : "Изберете стандардна локација за вашите прикачените медиа датотеки",
    "Home" : "Дома",
    "Choose default Photos upload and Albums location" : "Стандардна локација за прикачени фотографии и локации на албуми",
    "Choose a different folder" : "Избери друга папка",
    "View" : "Погледни",
    "Media folders" : "Медија папки",
    "Choose the folders from where photos and videos are shown." : "Изберете ги папките од каде што се прикажуваат фотографиите и видеата.",
    "Upload folder" : "Папка за прикачување",
    "Choose the folder where photos and albums are uploaded to." : "Изберете ги папките од каде што се прикачуваат фотографиите и албумите.",
    "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографии"],
    "Unselect all" : "Од-означи се",
    "Add photos to this album" : "Додади фотографии во овој албум",
    "Manage collaborators for this album" : "Уреди соработници за овој албум",
    "Open actions menu" : "Отвори Мени со акции",
    "Edit album details" : "Уреди ги деталите на албумот",
    "Download all files in album" : "Преземи ги сите датотеки од албумот",
    "Delete album" : "Избриши албум",
    "Download selected files" : "Преземи ги означените датотеки",
    "Remove selection from album" : "Отстрани ги селектираните од албумот",
    "This album does not have any photos or videos yet!" : "Овој албум сеуште нема фотографии и видеа!",
    "Add photos to {albumName}" : "Додади фотографии во {albumName}",
    "Manage collaborators" : "Уреди соработници",
    "Save collaborators for this album." : "Зачувај соработници за овој албум.",
    "Cover photo for album {albumName}" : "Насловна фотографија за албумот {albumName}",
    "There is no album yet!" : "Сè уште нема албум!",
    "This person could not be found" : "Оваа личност неможе да се пронајде",
    "Rename person" : "Преименувај личност",
    "Merge with different person" : "Спој со друга личност",
    "Download selected photos" : "Преземи ги означените фотографии",
    "Remove from favorites" : "Отстрани од фаворити",
    "Remove person" : "Отстрани личност",
    "Name of this person" : "Име на личноста",
    "Save." : "Зачувај.",
    "Merge person" : "Спој личност",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Премести ја фотографијата до друга особа","Премести ги фотографиите до друга особа"],
    "_Remove photo from person_::_Remove photos from person_" : ["Отстрани фотографија од личност","Отстрани фотографии од личност"],
    "This might take some time depending on the size of your photo library." : "Ова може да потрае некое време во зависност од големината на вашата збирка со фотографии.",
    "Recognized people will show up here" : "Препознатите луѓе ќе се појават овде",
    "This folder does not exist" : "Папката не постои",
    "Loading folders…" : "Се вчитуваат папките…",
    "No photos in here" : "Овде нема фотографии",
    "Taken on {date} at {time}" : "Направена на {date} во {time}",
    "This place does not have any photos or videos yet!" : "Ова место сеуште нема фотографии и видеа!",
    "Add photos to this place" : "Додади фотографии во ова место",
    "Cover photo for place {placeName}" : "Насловна фотографија за местото {placeName}",
    "There is no place yet!" : "Сè уште нема места!",
    "Cover photo for shared album {albumName}" : "Насловна фотографија за споделениот албум {albumName}",
    "Back to tags overview" : "Назад до преглед на ознаки",
    "No photos with this tag yet" : "Сеуште нема фотографии со оваа ознака",
    "No tags yet" : "Сеуште нема ознаки",
    "Photos with tags will show up here" : "Фотографиите со ознаки ќе се појават овде",
    "Popular tags" : "Популарни ознаки",
    "All tags" : "Сите ознаки",
    "Create new album from filters" : "Креирај нов албум од филтрите",
    "One of the source folders does not exist" : "Една од папките на постои",
    "Add to album" : "Додади во албум",
    "Delete selection" : "Избриши ги селектираните",
    "No photos or videos in here" : "Овде нема фотографии или видеа",
    "Failed to fetch collection." : "Неуспешно добивање на колекциите.",
    "Failed to fetch collections list." : "Неуспешно добивање на листата со колекции.",
    "Failed to fetch faces list." : "Неуспешно вчитување на листата со личности.",
    "All your media" : "Сите ваши медиа датотеки",
    "Album {title}" : "Албум {title}",
    "Shared Albums" : "Споделени албуми",
    "Shared album {title}" : "Споделен албум {title}",
    "Public album {title}" : "Јавен албум {title}",
    "Tagged photos" : "Означени фотографии",
    "Tagged photo {title}" : "Означена фотографија {title}",
    "{title}'s face" : "Лицето на {title}",
    "Last week" : "Минатата недела",
    "Last Month" : "Минатиот месец",
    "{startDate} to {endDate}" : "{startDate} до {endDate}",
    "Details" : "Детали",
    "Group" : "Група",
    "Remove {collaboratorLabel} from the collaborators list" : "Избриши {collaboratorLabel} од листата на соработници",
    "Back to {folder}" : "Назад кон {folder}",
    "Share this folder" : "Сподели ја оваа папка",
    "Loading folders …" : "Се вчитуваат папките…",
    "One of the source folders does not exists" : "Една од папките на постои",
    "Add" : "Додади"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
